import { Config, ESLintOptions } from './types';
import { Options } from '../common/types';
/**
 * Get an options object that can be used directly with ESLint's CLIEngine.
 *
 * @param options A config object that lets the user customize how Lynt works.
 * @return An object that is compatible with ESLint's CLIEngine options format.
 */
declare function getESLintOptions(options: Options): ESLintOptions;
/**
 * Get the ESLint config for lynt. Optionally adds extra React or Flow rules if
 * their corresponding flags are passed.
 *
 * @param options A configuration object that lets you customize how lynt works.
 * @return An object that is compatible with ESLint's config format.
 */
declare function getESLintConfig(options: Options): Config;
/**
 * Get the ESLint ignores for Lynt.
 *
 * @param userIgnores Additional ignore patterns to be added to the default.
 * @return The combined ignores.
 */
declare function getESLintIgnores(userIgnores?: Options['ignore']): Array<string>;
export { getESLintOptions, getESLintConfig, getESLintIgnores };
